@@ -5,6 +5,7 @@ import json
 import typing
 from functools import cached_property
 from urllib.parse import parse_qs
+from attr import has
 
 from fastutils import fsutils
 
@@ -14,10 +15,11 @@ from .exceptions import PayloadTooLarge
 class HttpRequest(object):
 
     post_size_limit = 1024*1024*2
-    temporary_file_path = None
+    temporary_path = None
 
-    def __init__(self, env):
+    def __init__(self, env, application):
         self.env = env
+        self.application = application
         self.read_all_content_flag = False
         self.is_content_ready = False
         self.is_files_ready = False
@@ -27,8 +29,8 @@ class HttpRequest(object):
         self._files = {}
 
     @classmethod
-    def set_temporary_file_path(cls, path):
-        cls.temporary_file_path = path
+    def set_temporary_path(cls, path):
+        cls.temporary_path = path
 
     @classmethod
     def set_post_size_limit(cls, limit:int=1024*1024*2):
@@ -139,6 +141,8 @@ class HttpRequest(object):
 
     @cached_property
     def boundary(self) -> typing.Optional[str]:
+        if not self.content_type:
+            return None
         if not self.content_type.startswith("multipart/form-data; boundary="):
             return None
         bs = re.findall("^multipart/form-data; boundary=(.*)$", self.content_type)
@@ -155,7 +159,6 @@ class HttpRequest(object):
         self.is_files_ready = True
 
     def read_input(self, read_all_files=False):
-
         if self.is_content_ready and self.is_files_ready:
             return
 
@@ -205,8 +208,6 @@ class HttpRequest(object):
             self.is_files_ready = True
             return
 
-        
-
 class WsgiInputBlockHandler(object):
     
     class BlockType:
@@ -237,7 +238,7 @@ class WsgiInputBlockHandler(object):
                 if info["filename"]:
                     self.block_type = self.BlockType.FileData
                     self.filename = info["filename"].decode("utf-8")
-                    self.file = HttpRequestFile(original_filename=self.filename, workspace=self.http_request.temporary_file_path)
+                    self.file = HttpRequestFile(original_filename=self.filename, workspace=self.http_request.temporary_path)
                     self.file.open("wb")
                     self.file_lastline = None
                 else:
@@ -262,9 +263,9 @@ class WsgiInputBlockHandler(object):
     def update_post_data(self, line):
         if self.block_name in self.http_request._post_data:
             if isinstance(self.http_request._post_data[self.block_name], str):
-                self.http_request._post_data[self.block_name] = [self.http_request] + [line.decode(self.block_encoding)]
+                self.http_request._post_data[self.block_name] = [self.http_request._post_data[self.block_name]] + [line[:-2].decode(self.block_encoding)]
             else:
-                self.http_request._post_data[self.block_name].append(line.decode(self.block_encoding))
+                self.http_request._post_data[self.block_name].append(line[:-2].decode(self.block_encoding))
         else:
             self.http_request._post_data[self.block_name] = line[:-2].decode(self.block_encoding)
 
