@@ -1,7 +1,9 @@
+import os
+import uuid
 import time
 import datetime
 from urllib.parse import quote
-
+from wsgiref.util import FileWrapper
 
 class HttpResponse(object):
 
@@ -128,11 +130,27 @@ class HttpResponse(object):
         self.headers = {}
         self.cookies = {}
         self.content = None
-        self.content_type = "text/html"
+        self.content_type = None
         self.content_encoding = "utf-8"
-        self.sendfile_stream = None
 
     def set_header(self, name, value, multiple=False):
+        """Set response header.
+
+        name: Header name.
+        value Header value.
+        multiple: If multiple==True, set the header many times. For example Set-Cookie header can be set many times.
+
+        # ######################################################################
+        # The header value must be plain ascii characters, so it shoud be encoded before assign to a header.
+        # You can use uri quote or base64 to do the string encode.
+        # ######################################################################
+
+        Examples:
+
+        from urllib.parse import quote
+        http_response.set_header("user-name", quote("张三"))
+
+        """
         name = name.lower()
         if not name in self.headers:
             self.headers[name] = []
@@ -140,7 +158,7 @@ class HttpResponse(object):
             self.headers[name].append(value)
         else:
             self.headers[name] = [value]
-        return self.headers[name]
+        return name, self.headers[name]
 
     def set_cookie(self, name:str, value:str, expires:datetime.datetime=None, max_age:int=None, domain:str=None, path:str="/", secure:bool=True, httpOnly:bool=True, sameSite:str=None):
         cookie_name, cookie_value = self.make_cookie(name, value, expires, max_age, domain, path, secure, httpOnly, sameSite)
@@ -172,7 +190,7 @@ class HttpResponse(object):
 
     @property
     def final_headers(self):
-        if not "content-type" in self.headers:
+        if self.content_type and (not "content-type" in self.headers):
             self.set_header("content-type", self.content_type)
         if not "set-cookie" in self.headers:
             for _, cookie_value in self.cookies.items():
@@ -194,6 +212,8 @@ class HttpResponse(object):
     def final_content(self):
         if self.content is None:
             return None
+        if isinstance(self.content, FileWrapper):
+            return self.content
         if isinstance(self.content, bytes):
             return self.content
         if isinstance(self.content, str):
@@ -201,46 +221,122 @@ class HttpResponse(object):
         return str(self.content).encode(self.content_encoding)
 
     # 301
+    def redirect_permanent(self, url, status_code=301):
+        self.status_code = status_code
+        self.set_header("location", url)
+        return self
+    
     # 302
+    def redirect_temporary(self, url, status_code=302):
+        self.status_code = status_code
+        self.set_header("location", url)
+        return self
+
+    # alias for 301 & 302
     def redirect(self, url, permanent=False):
         if permanent:
-            self.status_code = 301 # permanent redirect
+            return self.redirect_permanent(url)
         else:
-            self.status_code = 302 # temporary redirect
-        self.set_header("location", url)
-        return
+            return self.redirect_temporary(url)
 
     # 403
-    def forbidden(self, message=None):
-        self.status_code = 403
+    def forbidden(self, message=None, status_code=403, content_type="text/html"):
+        self.status_code = status_code
+        self.content_type = content_type
         self.content = message or self.DEFAULT_FORBIDDEN_MESSAGE
-        return
+        return self
 
     # 404
-    def not_found(self, message=None):
-        self.status_code = 404
+    def not_found(self, message=None, status_code=404, content_type="text/html"):
+        self.status_code = status_code
+        self.content_type = content_type
         self.content = message or self.DEFAULT_NOT_FOUND_MESSAGE.format(path=self.request.path)
-        return
+        return self
 
     # 405
-    def not_allowed(self, method, permitted_methods, message=None):
-        self.status_code = 405
+    def not_allowed(self, method, permitted_methods, message=None, status_code=405, content_type="text/html"):
+        self.status_code = status_code
+        self.content_type = content_type
         self.set_header("allow", ", ".join(permitted_methods))
         self.content = message or self.DEFAULT_NOT_ALLOWED_MESSAGE.format(method=method, permitted_methods=permitted_methods)
-        return
+        return self
 
     # 411
-    def length_required(self, message=None):
-        self.status_code = 411
+    def length_required(self, message=None, status_code=411, content_type="text/html"):
+        self.status_code = status_code
+        self.content_type = content_type
         self.content = message or self.DEFAULT_LENGTH_REQUIRED_MESSAGE
+        return self
     # 413
-    def payload_too_large(self, content_length, payload_max_size_limit, message=None, ):
-        self.status_code = 413
+    def payload_too_large(self, content_length, payload_max_size_limit, message=None, status_code=413, content_type="text/html"):
+        self.status_code = status_code
+        self.content_type = content_type
         self.content = message or self.DEFAULT_PAYLOAD_TOO_LARGE_MESSAGE.format(content_length=content_length, payload_max_size_limit=payload_max_size_limit)
-        return
+        return self
 
     # 200
-    def response(self, content):
-        self.status_code = 200
+    def response_html(self, content, status_code=200, content_type="text/html"):
+        self.status_code = status_code
+        self.content_type = content_type
         self.content = content
-        return
+        return self
+
+    # 200
+    response = response_html
+
+    # 200
+    def response_text(self, content, status_code=200, content_type="text/plain"):
+        self.status_code = status_code
+        self.content_type = content_type
+        self.content = content
+        return self
+
+    # 200
+    def response_file(self, thefile, filename=None, chunk=4096, status_code=200, content_type="application/octet-stream"):
+        """Response a file.
+
+        thefile: A file path or a opened file object.
+        filename: Sugguest filename for downloaded file.
+            If filename is None and thefile is a file path,
+            then the file's basename will be used.
+            If filename is None and thefile is a opened file instance,
+            then the name attr value of thefile is used a the file's path.
+            If filename is None and thefile is a opened file instance but failed to get the value of it's name attr,
+            then the TIMESTAMP.dat will be used.
+            The TIMESTAMP is the current timestamp integer value.
+        chunk: Chunk size. Default to 4096 bytes.
+
+        Examples:
+
+        http_response.response_file("/tmp/a.txt")
+        
+        fobj = open("/tmp/a.txt", "rb")
+        http_response.response_file(fobj, "hello world.txt")
+
+
+        """
+        if isinstance(thefile, str):
+            fobj = open(thefile, "rb")
+            filename = filename or os.path.basename(thefile)
+        else:
+            fobj = thefile
+            if not filename:
+                filename = getattr(fobj, "name", None)
+                if filename:
+                    filename = os.path.basename(filename)
+            if not filename:
+                filename = getattr(fobj, "filename", None)
+                if filename:
+                    filename = os.path.basename(filename)
+            if not filename:
+                filename = getattr(fobj, "filepath", None)
+                if filename:
+                    filename = os.path.basename(filename)
+            if not filename:
+                filename = int(time.time()) + ".dat"
+        filename = quote(filename)
+        self.status_code = status_code
+        self.content_type = content_type
+        self.set_header("content-disposition", "attachment; filename={}".format(filename))
+        self.content = FileWrapper(fobj, chunk)
+        return self
